@@ -8,6 +8,7 @@ from tkinter import filedialog
 from tkinter.ttk import Combobox
 from lxml import etree
 import datetime
+from . import tooltip as TP
 
 def get_boxes_and_destroy():
     global notes_dict
@@ -23,11 +24,12 @@ def get_boxes_and_destroy():
     quit()
 
 def delete_note(root, _id):
-    for item in root[2].iter():
-        for subelem in item.findall('Id'):
-            if subelem.text == _id:
-                root[2].remove(item)
-                print('removed note: ' + _id)
+    for notes in root.findall('{http://schemas.datacontract.org/2004/07/ThreatModeling.Model}Notes'):
+        for note in notes.findall('{http://schemas.datacontract.org/2004/07/ThreatModeling.Model}Note'):
+            for id in note.findall('{http://schemas.datacontract.org/2004/07/ThreatModeling.Model}Id'):
+                if int(id.text) == int(_id):
+                    root[2].remove(note)
+                    print('removed note: ' + str(_id))
     return
 
 def save_to_xml():
@@ -70,7 +72,6 @@ def save_to_xml():
                 print("Warning: model already contains METADATA note")
                 print("Overwriting note..")
                 id = int(key)
-                # delete
                 delete_note(_root, id)
 
     new_note = etree.Element("Note")
@@ -93,61 +94,6 @@ def save_to_xml():
     tree.write(model_path)
     return
 
-
-class CreateToolTip(object):
-    """
-    create a tooltip for a given widget
-    """
-    def __init__(self, widget, text='widget info'):
-        self.waittime = 500     #miliseconds
-        self.wraplength = 180   #pixels
-        self.widget = widget
-        self.text = text
-        self.widget.bind("<Enter>", self.enter)
-        self.widget.bind("<Leave>", self.leave)
-        self.widget.bind("<ButtonPress>", self.leave)
-        self.id = None
-        self.tw = None
-
-    def enter(self, event=None):
-        self.schedule()
-
-    def leave(self, event=None):
-        self.unschedule()
-        self.hidetip()
-
-    def schedule(self):
-        self.unschedule()
-        self.id = self.widget.after(self.waittime, self.showtip)
-
-    def unschedule(self):
-        id = self.id
-        self.id = None
-        if id:
-            self.widget.after_cancel(id)
-
-    def showtip(self, event=None):
-        x = y = 0
-        x, y, cx, cy = self.widget.bbox("insert")
-        x += self.widget.winfo_rootx() + 25
-        y += self.widget.winfo_rooty() + 20
-        # creates a toplevel window
-        self.tw = tk.Toplevel(self.widget)
-        # Leaves only the label and removes the app window
-        self.tw.wm_overrideredirect(True)
-        self.tw.wm_geometry("+%d+%d" % (x, y))
-        label = tk.Label(self.tw, text=self.text, justify='left',
-                       background="#ffffff", relief='solid', borderwidth=1,
-                       wraplength = self.wraplength)
-        label.pack(ipadx=1)
-
-    def hidetip(self):
-        tw = self.tw
-        self.tw= None
-        if tw:
-            tw.destroy()
-
-
 def main():
     root = tk.Tk()
     root.configure(background='#404040')
@@ -163,9 +109,9 @@ def main():
     # Create text widget and specify size. 
     T1 = ttk.Label(root, text='Compliance Standards:', font=(None, 13, 'bold'))
     T2 = ttk.Label(root, text='Security Requirements:', font=(None, 13, 'bold'))
-    T3 = ttk.Label(root, text='Confidentiality')
-    T4 = ttk.Label(root, text='Integrity')
-    T5 = ttk.Label(root, text='Availability')
+    T3 = ttk.Label(root, text='Confidentiality Requirement')
+    T4 = ttk.Label(root, text='Integrity Requirement')
+    T5 = ttk.Label(root, text='Availability Requirement')
     T6 = ttk.Label(root, text='Target Distribution')
     R1= Button(root, text="Done", command=get_boxes_and_destroy)
 
@@ -207,12 +153,15 @@ def main():
     R1.place(x=150,y=318)
 
     # have-over definitions
-    CreateToolTip(T1, \
-        "select the desired compliance standards. Compliance tag URLs will show up in the generated report"
+    TP.CreateToolTip(T1, \
+        "Select the desired compliance standards. Compliance tag URLs will show up in the generated report"
         " after fixing the hyperlinks with TMTool")
-    CreateToolTip(T2, \
-        "determine the specific security requirements for confidentiality, integrity and availability. "
-        "This allows the final score to be tuned according to the users' environment.")
+    TP.CreateToolTip(T2, \
+        "Determine the specific security requirements for confidentiality, integrity and availability. "
+        "This allows the final score to be tuned according to the users' environment and is similar to the users' risk threshold")
+    TP.CreateToolTip(T6, \
+        "Determine the proportion of vulnerable systems within the model. "
+        "Ex: a threat ID affects only Windows, but half the environment systems run MacOS. Can be over ridden in analysis mode.")
 
     root.mainloop()
     quit()
